#ifndef NT2_INCLUDE_FUNCTIONS_IDIVFIX_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_IDIVFIX_HPP_INCLUDED

#include <nt2/arithmetic/include/functions/idivfix.hpp>

#endif
